#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <stdarg.h>
#include <limits.h>

#include "config.h"
#include "imapfilter.h"
#include "log.h"


extern int options;
extern account_data account;
static FILE *logfp;		/* Points to logfile. */


/*
 * Print message if in OPTION_DETAILS_VERBOSE mode.
 */
void verbose(const char *info, ...)
{
    va_list args;

    if (options & OPTION_DETAILS_VERBOSE) {
	va_start(args, info);
	vprintf(info, args);
	va_end(args);
    }
}

/*
 * Prints error message and writes it into logfile.
 */
void error(const char *errmsg, ...)
{
    va_list args;

    va_start(args, errmsg);

    if (account.logfile[0]) {
	vfprintf(logfp, errmsg, args);
    }

    vfprintf(stderr, errmsg, args);
    va_end(args);
}


/*
 * Opens the file to save logging information.
 */
int open_logfile(void)
{
    if (!(account.logfile[0]))
	return SUCCESS;		/* Logging not enabled. */

#ifdef DEBUG
    printf("debug: logfile: %s\n", account.logfile);
#endif

    logfp = fopen(account.logfile, "a");

    if (!logfp) {
	fprintf(stderr, "imapfilter: opening logfile %s: %s\n",
		account.logfile, strerror(errno));
	return FAILURE;
    }

    return SUCCESS;
}


/*
 * Closes the logfile.
 */
int close_logfile(void)
{
    if (!(account.logfile[0]))
	return SUCCESS;
    else
	return fclose(logfp);
}


/*
 * Writes information to logfile.
 */
void log_info(const char *info, ...)
{
    va_list args;

    if (account.logfile[0]) {
	va_start(args, info);
	vfprintf(logfp, info, args);
	va_end(args);
    }
}
